@@ -1,3 +1,5 @@
+#-*- coding:utf-8 -*-
+
 """
 This file is part of OpenSesame.
 
@@ -16,7 +18,6 @@ along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from libopensesame import sketchpad, exceptions
-import shlex
 
 class feedback(sketchpad.sketchpad):
 
@@ -63,7 +64,8 @@ class feedback(sketchpad.sketchpad):
 			if not sketchpad.sketchpad.prepare(self):
 				return False
 		except exceptions.script_error as e:
-			raise exceptions.runtime_error("Failed to create feedback item '%s'" % self.name)						
+			raise exceptions.runtime_error("Failed to create feedback item '%s'" \
+				% self.name)						
 		if not sketchpad.sketchpad.run(self):
 			return False			
 		
