@@ -98,24 +98,31 @@ class inline_script(item.item):
 		
 		item.item.prepare(self)
 		if self.experiment.transparent_variables == u'yes':
-			self.start_transparency()
-		
+			self.start_transparency()		
 		# Convenience variables need to be registered as globals. By specifying
 		# a __name__, the script will function as a module, so that e.g. import
 		# statements do not suffer from locality.
 		if u'exp' not in _globals:
 			_globals[u'exp'] = self.experiment
-			_globals[u'win'] = self.experiment.window
-			_globals[u'self'] = self
+			_globals[u'win'] = self.experiment.window			
 			_globals[u'__name__'] = u'myname'
+		# 'self' must always be registered, otherwise we get confusions between
+		# the various inline_script items.
+		_globals[u'self'] = self
+		# Prepend source encoding (PEP 0263) and encode scripts. This is
+		# necessary, because the exec statement doesn't take kindly to Unicode.
+		_prepare = (u'#-*- coding:%s -*-\n' % self.encoding + self._prepare) \
+			.encode(self.encoding)
+		_run = (u'#-*- coding:%s -*-\n' % self.encoding + self._run) \
+			.encode(self.encoding)			
 		# Compile prepare script
 		try:
-			self.cprepare = compile(self._prepare, u'<string>', u'exec')
+			self.cprepare = compile(_prepare, u'<string>', u'exec')
 		except Exception as e:
 			raise exceptions.inline_error(self.name, u'prepare', e)
 		# Compile run script
 		try:
-			self.crun = compile(self._run, u'<string>', u'exec')
+			self.crun = compile(_run, u'<string>', u'exec')
 		except Exception as e:
 			raise exceptions.inline_error(self.name, u'run', e)
 		# Run prepare script
@@ -134,7 +141,9 @@ class inline_script(item.item):
 		</DOC>"""
 		
 		global _globals, _locals
-
+		# 'self' must always be registered, otherwise we get confusions between
+		# the various inline_script items.
+		_globals[u'self'] = self
 		if self.experiment.transparent_variables == u'yes':
 			self.start_transparency()
 		try:
