@@ -27,12 +27,9 @@ import pygame
 
 class item(object):
 
-	"""
-	item is an abstract class that serves as the basis for all OpenSesame items,
-	such as sketchpad, keyboard_response, experiment, etc.
-	"""
+	"""Abstract class that serves as the basis for all OpenSesame items."""
 
-	encoding = 'UTF-8'
+	encoding = u'utf-8'
 
 	def __init__(self, name, experiment, string=None):
 
@@ -51,64 +48,58 @@ class item(object):
 		self.experiment = experiment
 		self.debug = debug.enabled
 		self.count = 0
-
 		# A number of keywords are reserved, which means that they cannot be
 		# used as variable names
 		self.reserved_words = [u'experiment', u'variables', u'comments', \
 			u'item_type']
 		for attr in dir(item):
-			if hasattr(getattr(item, attr), '__call__'):
+			if hasattr(getattr(item, attr), u'__call__'):
 				self.reserved_words.append(attr)
 
 		self._get_lock = None
-
-		if not hasattr(self, u'item_type'):
-			prefix = self.experiment.item_prefix()
-			self.item_type = self.__class__.__name__
-			if self.item_type.startswith(prefix):
-				self.item_type = self.item_type[len(prefix):]
+		# item_type shouldn't be explicitly set anymore.
+		if hasattr(self, u'item_type'):
+			debug.msg(u'item_type has been set explicitly in item "%s"' % \
+			self.name, reason=u'deprecation')
+		# Deduce item_type from class name
+		prefix = self.experiment.item_prefix()
+		self.item_type = unicode(self.__class__.__name__)
+		if self.item_type.startswith(prefix):
+			self.item_type = self.item_type[len(prefix):]			
 		if not hasattr(self, u'description'):
 			self.description = u'Default description'
 		if not hasattr(self, u'round_decimals'):
 			self.round_decimals = 2
 		self.variables = {}
 		self.comments = []
-
 		if string != None:
 			self.from_string(string)
 
 	def prepare(self):
 
-		"""
-		Derived classes should use this function to prepare the item for speedy
-		execution during the run phase.
-		"""
+		"""Implements the prepare phase of the item."""
 
 		self.time = self.experiment._time_func
 		self.sleep = self.experiment._sleep_func
-		self.experiment.set("count_%s" % self.name, self.count)
-		self.count += 1
-		return True
+		self.experiment.set(u'count_%s' % self.name, self.count)
+		self.count += 1		
 
 	def run(self):
 
-		"""
-		Derived classes should use this function to perform the item specific
-		function.
-		"""
+		"""Implements the run phase of the item."""
 
-		return True
+		pass
 
 	def parse_variable(self, line):
 
 		"""
-		Reads a single variable from a single definition line
+		Reads a single variable from a single definition line.
 
 		Arguments:
-		line -- a single definition line
+		line	--	A single definition line.
 
 		Returns:
-		True on succes, False on failure
+		True on succes, False on failure.
 		"""
 
 		# It is a little ugly to call parse_comment() here, but otherwise
@@ -119,45 +110,44 @@ class item(object):
 		if len(l) > 0 and l[0] == u'set':
 			if len(l) != 3:
 				raise exceptions.script_error( \
-					u"Error parsing variable definition: '%s'" % line)
+					u'Error parsing variable definition: "%s"' % line)
 			else:
 				self.set(l[1], l[2])
 				return True
-
 		return False
 
 	def parse_keywords(self, line, unsanitize=False, _eval=False):
 
 		"""
-		Parses keywords, e.g. 'my_keyword=my_value'
+		Parses keywords, e.g. 'my_keyword=my_value'.
 
 		Arguments:
-		line -- a single definition line
+		line		--	A single definition line.
 
 		Keyword arguments:
-		unsanitize -- DEPRECATED KEYWORD
-		_eval -- indicates whether the values should be evaluated
-				 (default=False)
+		unsanitize	--	DEPRECATED KEYWORD.
+		_eval		--	Indicates whether the values should be evaluated.
+						(default=False)
 
 		Returns:
-		A keyword => value dictionary
+		A value dictionary with keywords as keys and values as values.
 		"""
 
 		# Parse keywords
 		l = self.split(line.strip())
 		keywords = {}
 		for i in l:
-			j = i.find("=")
+			j = i.find(u'=')
 			if j != -1:
 				# UGLY HACK: if the string appears to be plain text,
 				# rather than a keyword, for example something like
 				# 'accuracy = [acc]%', do not parse it as a keyword-
 				# value pair. The string needs to occur only once in
 				# the full line, both quoted and unquoted.
-				q = "\"" + i + "\""
+				q = u'"%s"' % i
 				if line.count(q) == 1 and line.count(i) == 1:
 					debug.msg( \
-						"'%s' does not appear to be a keyword-value pair in string '%s'" \
+						u'"%s" does not appear to be a keyword-value pair in string "%s"' \
 						% (i, line))
 				else:
 					var = str(i[:j])
@@ -170,10 +160,10 @@ class item(object):
 	def parse_line(self, line):
 
 		"""
-		Allows for arbitrary line parsing, for item-specific requirements
+		Allows for arbitrary line parsing, for item-specific requirements.
 
 		Arguments:
-		line -- a single definition line
+		line	--	A single definition line.
 		"""
 
 		pass
@@ -181,20 +171,20 @@ class item(object):
 	def parse_comment(self, line):
 
 		"""
-		Parses comments from a single definition line, indicated by # // or '
+		Parses comments from a single definition line, indicated by # // or '.
 
 		Arguments:
-		line -- a single definition line
+		line	--	A single definition line.
 
 		Returns:
-		True on succes, False on failure
+		True on succes, False on failure.
 		"""
 
 		line = line.strip()
-		if len(line) > 0 and line[0] == "#":
+		if len(line) > 0 and line[0] == u'#':
 			self.comments.append(line[1:])
 			return True
-		elif len(line) > 1 and line[0:2] == "//":
+		elif len(line) > 1 and line[0:2] == u'//':
 			self.comments.append(line[2:])
 			return True
 		return False
@@ -202,17 +192,16 @@ class item(object):
 	def variable_to_string(self, var):
 
 		"""
-		Encode a variable into a definition string
+		Encodes a variable into a definition string.
 
 		Arguments:
-		var -- the variable to encode
+		var		--	The variable to encode.
 
 		Returns:
-		A definition string
+		A definition string.
 		"""
-
+		
 		val = self.unistr(self.variables[var])
-
 		# Multiline variables are stored as a block
 		if u'\n' in val or u'"' in val:
 			s = u'__%s__\n' % var
@@ -222,7 +211,6 @@ class item(object):
 				s = s[:-1]
 			s += u'\n\t__end__\n'
 			return s
-
 		# Regular variables
 		else:
 			return u'set %s "%s"\n' % (var, val)
@@ -230,10 +218,10 @@ class item(object):
 	def from_string(self, string):
 
 		"""
-		Parse the item from a definition string
+		Parses the item from a definition string.
 
 		Arguments:
-		string -- the definition string
+		string	--	The definition string.
 		"""
 
 		debug.msg()
@@ -245,7 +233,7 @@ class item(object):
 			if line_stripped == u'__end__':
 				if textblock_var == None:
 					self.experiment.notify( \
-						'It appears that a textblock has been closed without being opened. The most likely reason is that you have used the string "__end__", which has a special meaning for OpenSesame.')
+						u'It appears that a textblock has been closed without being opened. The most likely reason is that you have used the string "__end__", which has a special meaning for OpenSesame.')
 				else:
 					self.set(textblock_var, textblock_val)
 					textblock_var = None
@@ -278,10 +266,11 @@ class item(object):
 	def to_string(self, item_type=None):
 
 		"""
-		Encode the item into an OpenSesame definition string
+		Encodes the item into an OpenSesame definition string.
 
 		Keyword arguments:
-		item_type -- the type of the item or None for autodetect (default=None)
+		item_type	--	The type of the item or None for autodetect.
+						(default=None)
 
 		Returns:
 		The unicode definition string
@@ -311,10 +300,11 @@ class item(object):
 		A (width, height) tuple
 		</DOC>"""
 
-		w = self.get('width')
-		h = self.get('height')
+		w = self.get(u'width')
+		h = self.get(u'height')
 		if type(w) != int or type(h) != int:
-			raise exceptions.runtime_error('(%s, %s) is not a valid resolution')
+			raise exceptions.runtime_error( \
+				u'(%s, %s) is not a valid resolution' % (w, h))
 		return w, h
 
 	def set(self, var, val):
@@ -348,14 +338,14 @@ class item(object):
 		var = self.unistr(var)
 		val = self.auto_type(val)
 		# Check whether the variable name is valid
-		if regexp.sanitize_var_name.sub('_', var) != var:
+		if regexp.sanitize_var_name.sub(u'_', var) != var:
 			raise exceptions.runtime_error( \
-				'"%s" is not a valid variable name. Variable names must consist of alphanumeric characters and underscores, and may not start with a digit.' \
+				u'"%s" is not a valid variable name. Variable names must consist of alphanumeric characters and underscores, and may not start with a digit.' \
 				% var)
 		# Check whether the variable name is not protected
 		if var in self.reserved_words:
 			raise exceptions.runtime_error( \
-				'"%s" is a reserved keyword (i.e. it has a special meaning for OpenSesame), and therefore cannot be used as a variable name. Sorry!' \
+				u'"%s" is a reserved keyword (i.e. it has a special meaning for OpenSesame), and therefore cannot be used as a variable name. Sorry!' \
 				% var)
 
 		# Register the variables
@@ -596,7 +586,7 @@ class item(object):
 
 		if time == None:
 			time = self.time()
-		setattr(self.experiment, 'time_%s' % self.name, time)
+		setattr(self.experiment, u'time_%s' % self.name, time)
 
 	def dummy(self, **args):
 
@@ -655,7 +645,7 @@ class item(object):
 				val = self.get(var)
 				# Quote strings if necessary
 				if type(val) == unicode and quote_str:
-					val = u"\'" + val + u"\'"
+					val = u"'" + val + u"'"
 				# Round floats
 				elif round_float and type(val) == float:
 					val = float_template % val
@@ -686,20 +676,20 @@ class item(object):
 		# If the conditional statement is preceded by a '=', it is interpreted as
 		# Python code, like 'self.get("correct") == 1'. In this case we only have
 		# to strip the preceding space
-		if len(src) > 0 and src[0] == '=':
+		if len(src) > 0 and src[0] == u'=':
 			code = src[1:]
-			debug.msg('Python-style conditional statement: %s' % code)
+			debug.msg(u'Python-style conditional statement: %s' % code)
 
 		# Otherwise, it is interpreted as a traditional run if statement, like
 		# '[correct] = 1'
 		else:
-			operators = "!=", "==", "=", "<", ">", ">=", "<=", "+", "-", "(", \
-				")", "/", "*", "%", "~", "**", "^"
-			op_chars = "!", "=", "=", "<", ">", "+", "-", "(", ")", "/", "*", \
-				"%", "~", "*", "^"
-			whitespace = " ", "\t", "\n"
-			keywords = "and", "or", "is", "not", "true", "false"
-			capitalize = "true", "false", "none"
+			operators = u"!=", u"==", u"=", u"<", u">", u">=", u"<=", u"+", \
+				u"-", u"(", u")", u"/", u"*", u"%", u"~", u"**", u"^"
+			op_chars = u"!", u"=", u"=", u"<", u">", u"+", u"-", u"(", u")", \
+				u"/", u"*", u"%", u"~", u"*", u"^"
+			whitespace = u" ", u"\t", u"\n"
+			keywords = u"and", u"or", u"is", u"not", u"true", u"false"
+			capitalize = u"true", u"false", u"none"
 
 			# Try to fix missing spaces
 			redo = True
@@ -742,15 +732,15 @@ class item(object):
 						l.append(self.unistr(word))
 				i += 1
 
-			code = " ".join(l)
-			if code != "True":
-				debug.msg("'%s' => '%s'" % (src, code))
+			code = u" ".join(l)
+			if code != u"True":
+				debug.msg(u"'%s' => '%s'" % (src, code))
 
 		# Optionally compile the conditional statement to bytecode and return
 		if not bytecode:
 			return code
 		try:
-			bytecode = compile(code, "<conditional statement>", "eval")
+			bytecode = compile(code, u"<conditional statement>", u"eval")
 		except:
 			raise exceptions.runtime_error( \
 				u"'%s' is not a valid conditional statement in sequence item '%s'" \
@@ -796,9 +786,9 @@ class item(object):
 		s = self.unistr(s)
 		if strict:
 			if allow_vars:
-				return regexp.sanitize_strict_vars.sub('', s)
-			return regexp.sanitize_strict_novars.sub('', s)
-		return regexp.sanitize_loose.sub('', s)
+				return regexp.sanitize_strict_vars.sub(u'', s)
+			return regexp.sanitize_strict_novars.sub(u'', s)
+		return regexp.sanitize_loose.sub(u'', s)
 
 	def usanitize(self, s, strict=False):
 
@@ -818,10 +808,10 @@ class item(object):
 		notation
 		"""
 
-		if type(s) != unicode:
+		if not isinstance(s, unicode):
 			raise exceptions.runtime_error( \
-			'usanitize() expects first argument to be unicode, not "%s"' \
-			% type(s))
+				u'usanitize() expects first argument to be unicode, not "%s"' \
+				% type(s))
 
 		_s = ''
 		for ch in s:
@@ -831,7 +821,7 @@ class item(object):
 					_s += 'U+%.4X' % ord(ch)
 			else:
 				_s += ch
-		return _s.replace(os.linesep, "\n")
+		return _s.replace(os.linesep, '\n')
 
 
 	def unsanitize(self, s):
@@ -846,16 +836,15 @@ class item(object):
 		A unicode string with special characters
 		"""
 
-		if type(s) not in (str, unicode):
+		if not isinstance(s, basestring):
 			raise exceptions.runtime_error( \
-			'unsanitize() expects first argument to be unicode, not "%s"' \
+			u'unsanitize() expects first argument to be unicode or str, not "%s"' \
 			% type(s))
-
 		s = self.unistr(s)
 		while True:
 			m = regexp.unsanitize.search(s)
 			if m == None:
-				break
+				break			
 			s = s.replace(m.group(0), unichr(int(m.group(1), 16)), 1)
 		return s
 
@@ -878,7 +867,10 @@ class item(object):
 			return val
 		# Regular strings need to be encoded using the correct encoding
 		if isinstance(val, str):
-			return unicode(val, encoding=self.encoding, errors='replace')
+			return unicode(val, encoding=self.encoding, errors=u'replace')
+		# Numeric values are encoded right away
+		if isinstance(val, int) or isinstance(val, float):
+			return unicode(val)
 		# Some types need to be converted to unicode, but require the encoding
 		# and errors parameters. Notable examples are Exceptions, which have
 		# strange characters under some locales, such as French. It even appears
@@ -886,7 +878,7 @@ class item(object):
 		# Presumably, there is a better way to do this, but for now this at
 		# least gives sensible results.
 		try:
-			return unicode(str(val), encoding=self.encoding, errors='replace')
+			return unicode(str(val), encoding=self.encoding, errors=u'replace')
 		except:
 			pass
 		# For other types, the unicode representation doesn't require a specific
@@ -990,7 +982,7 @@ class item(object):
 		>>> self.log('TIMESTAMP = %s' % self.time())
 		</DOC>"""
 
-		self.experiment._log.write(u"%s\n" % msg)
+		self.experiment._log.write(u'%s\n' % msg)
 
 	def flush_log(self):
 
