@@ -46,15 +46,15 @@ class image(widget):
 		</DOC>"""		
 	
 		if type(adjust) != bool:
-			adjust = adjust == 'yes'			
+			adjust = adjust == u'yes'			
 		if type(frame) != bool:
-			frame = frame == 'yes'						
+			frame = frame == u'yes'						
 	
 		widget.__init__(self, form)
 		self.adjust = adjust
 		self.frame = frame
 		self.path = path
-		self.type = 'image'
+		self.type = u'image'
 				
 	def render(self):
 	
@@ -64,7 +64,7 @@ class image(widget):
 	
 		if not os.path.exists(self.path):
 			raise exceptions.runtime_error( \
-				'No valid path has been specified in image widget')
+				u'No valid path has been specified in image widget')
 		
 		x, y, w, h = self.rect
 		x += w/2
@@ -95,7 +95,7 @@ class image(widget):
 					img = pygame.image.load(self.path)
 				except:
 					raise exceptions.runtime_error( \
-						'Failed to open image "%s". Perhaps the file is not an image, or the image format is not supported.' \
+						u'Failed to open image "%s". Perhaps the file is not an image, or the image format is not supported.' \
 						% self.path)
 				img_w, img_h = img.get_width()			
 			scale_x = 1.*w/img_w
