@@ -17,26 +17,23 @@ You should have received a copy of the GNU General Public License
 along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__author__ = "Sebastiaan Mathot"
-__license__ = "GPLv3"
-
 import sys
 if '--catch-translatables' in sys.argv:
 
 	# Automatically catches all strings that require translation
 	from libopensesame import misc
 	import os.path
-	path = misc.resource(os.path.join('ts', 'translatables.txt'))
+	path = misc.resource(os.path.join(u'ts', u'translatables.txt'))
 	def _(s):
-		l = open(path).read().split('\n')
+		l = open(path).read().split(u'\n')
 		if s not in l:
-			f = open(path, 'a')
-			f.write(s+'\n')
-			print 'New translatable: '+s
+			f = open(path, u'a')
+			f.write(s + u'\n')
+			print u'New translatable: '+s
 			f.close()
 		return s
 
 else:
 	# A simple wrapper arround the translate function
 	from PyQt4.QtCore import QCoreApplication
-	_ = lambda s: unicode(QCoreApplication.translate('script', s))
+	_ = lambda s: unicode(QCoreApplication.translate(u'script', s))
