@@ -24,16 +24,7 @@ import openexp.keyboard
 
 # Whitespace and empty strings are not acceptable names for keys. These should
 # be converted to descriptions, e.g. '\t' to 'tab'
-invalid_unicode = [''] + list(whitespace)
-
-# This is a crude keymap that allows you to convert into the corresponding keys
-# plus shift
-key_map = {
-	"1" : "!", "2" : "@", "3" : "#", "4" : "$", "5" : "%", "6" : "^", 
-	"7" : "&", "8" : "*", "9" : "(", "0" : ")", "-" : "_", "=" : "+",
-	"[" : "{", "]" : "}", "\\" : "|", ";" : ":", "\"" : "'", "," : "<",
-	"." : ">", "/" : "?"
-	}
+invalid_unicode = [u''] + list(whitespace)
 
 class legacy:
 
@@ -95,9 +86,9 @@ class legacy:
 		self.key_code_to_name = {}
 		self.key_name_to_code = {}		
 		for i in dir(pygame):
-			if i[:2] == "K_":
+			if i[:2] == u"K_":
 				code = getattr(pygame, i)
-				name1 = pygame.key.name(code).lower()
+				name1 = self.key_name(code).lower()
 				name2 = name1.upper()
 				name3 = i[2:].lower()
 				name4 = name3.upper()
@@ -196,12 +187,12 @@ class legacy:
 					continue
 				if event.key == pygame.K_ESCAPE:
 					raise openexp.exceptions.response_error( \
-						"The escape key was pressed.")
+						u"The escape key was pressed.")
 				if event.unicode in invalid_unicode or event.unicode not in \
 					printable:
-					key = pygame.key.name(event.key)
+					key = self.key_name(event.key)
 				else:
-					key = event.unicode
+					key = event.unicode				
 				if keylist == None or key in keylist:
 					return key, time				
 			if timeout != None and time-start_time >= timeout:
@@ -230,45 +221,35 @@ class legacy:
 		l = []
 		mods = pygame.key.get_mods()
 		if mods & KMOD_LSHIFT or mods & KMOD_RSHIFT or mods & KMOD_SHIFT:
-			l.append("shift")
+			l.append(u"shift")
 		if mods & KMOD_LCTRL or mods & KMOD_RCTRL or mods & KMOD_CTRL:
-			l.append("ctrl")
+			l.append(u"ctrl")
 		if mods & KMOD_LALT or mods & KMOD_RALT or mods & KMOD_ALT:
-			l.append("alt")
+			l.append(u"alt")
 		if mods & KMOD_LMETA or mods & KMOD_RMETA or mods & KMOD_META:
-			l.append("meta")
+			l.append(u"meta")
 		return l
 
-	def shift(self, key, mods=["shift"]):
+	def shift(self, key, mods=[u"shift"]):
 
 		"""
-		Returns the character that results from pressing a key together with the
-		moderators, typically a shift. E.g., "3" + "Shift" -> "#". This function
-		is not particularly elegant as it does not take locales into account and
-		assumes a standard US keyboard.
-
+		DEPRECATED
+		
+		This function has been deprecated as of 0.27.4. Shift is handled
+		transparently by keyboard.get_key()
+		
 		Arguments:
-		key -- A character.
-
+		key 	--	A key.
+		
 		Keyword arguments:
-		mods -- A list of keyboard moderators (default=["shift"]).
-
-		Returns:
-		The character that results from combining the input key with shift.
+		mods	--	A list of keyboard modifiers.
+		
+		Exception:
+		This function always raises an exception
 		"""
 
-		if key.isalpha():
-			if "shift" in mods:
-				return key.upper()
-			else:
-				return key.lower()
-
-		if "shift" in mods:
-			if key not in key_map:
-				return ""
-			return key_map[key]
-
-		return key
+		raise openexp.exceptions.response_error( \
+			u"keyboard.shift() is deprecated")
 
 	def to_int(self, key):
 
@@ -286,7 +267,7 @@ class legacy:
 		"""
 
 		raise openexp.exceptions.response_error( \
-			"keyboard.to_int() is deprecated")
+			u"keyboard.to_int() is deprecated")
 
 	def to_chr(self, key):
 
@@ -359,6 +340,21 @@ class legacy:
 				keypressed = True
 				if event.key == pygame.K_ESCAPE:
 					raise openexp.exceptions.response_error( \
-						"The escape key was pressed.")
+						u"The escape key was pressed.")
 		return keypressed
 
+	def key_name(self, key):
+		
+		"""
+		Returns the name that corresponds to a key code. This intercepts the
+		pygame.key.name() function, to prevent invalid names like '[1]'.
+		
+		Arguments:
+		key		--	A key code.
+		
+		Returns:
+		A unicode string corresponding to the key code.
+		"""
+		
+		return unicode(pygame.key.name(key)).replace(u'[', u'') \
+			.replace(u']', u'')
\ No newline at end of file
